import http.client
import daemon
from time import sleep

TIMEOUT: float = 1
TESTDOMAINS: list[str] = ["cscherr.de", "debian.org", "cloudflare.com"]

def check_net() -> bool:
    statuses: list[bool] = []
    for domain in TESTDOMAINS:
        status, msg = reachable(domain)
        statuses.append(status)
        print(f"{domain:60s} {msg}")

    overall = False
    for s in statuses:
        overall |= s
    return overall

def reachable(domain: str) -> tuple[bool, str]:
    try:
        conn = http.client.HTTPSConnection(domain, timeout=TIMEOUT)
        conn.request("GET", "/")
        r = conn.getresponse()
        conn.close()
        return True, r.status
    except Exception as e:
        return False, e.__str__()

def monitor():
    while True:
        try:
            b = check_net()
            if b: print(":SUCCESS:")
            else: print(":FAILURE:")
            sleep(4)
        except Exception as e:
            print(e)

if __name__ == "__main__":
    print("executing as normal script")
    monitor()

with daemon.DaemonContext():
    print("entering daemon mode")
    monitor()
